@@ -4,26 +4,21 @@ import os
 import re as _re
 import aiohttp
 import chardet
-import requests.models
+import webbrowser
 from urllib.parse import urlparse, urlunparse, urljoin
 from urllib3.exceptions import (
     DecodeError, ReadTimeoutError, ProtocolError)
-from requests.structures import CaseInsensitiveDict
-from requests.cookies import cookiejar_from_dict
-from requests.exceptions import (
-    HTTPError, ChunkedEncodingError, ContentDecodingError, ConnectionError, StreamConsumedError
-)
-from requests.utils import (
-    stream_decode_response_unicode, parse_header_links,
-    iter_slices, guess_json_utf
-)
-from requests.status_codes import codes
-
-from espider import UnicodeDammit, Request
-from espider.selector import Selector
-from requests.models import HTTPError, REDIRECT_STATI, codes
 from w3lib.encoding import http_content_type_encoding, html_body_declared_encoding
-import webbrowser
+
+from espider.selector import Selector
+from espider.request import Request
+from espider._utils._bs4 import UnicodeDammit
+from espider._utils._requests import (
+    ChunkedEncodingError, ContentDecodingError, ConnectionError, StreamConsumedError, HTTPError,
+    REDIRECT_STATI, codes, CaseInsensitiveDict,
+    stream_decode_response_unicode, parse_header_links, iter_slices, guess_json_utf,
+    cookiejar_from_dict
+)
 
 try:
     import simplejson as json
@@ -130,7 +125,7 @@ class Response(object):
                 'status_code': 'status'
             }
             attr_list = ['headers', 'cookies', 'method']
-            if isinstance(resp, requests.models.Response):
+            if isinstance(resp, Response):
                 self.__dict__.update(resp.__dict__)
             elif isinstance(resp, aiohttp.client_reqrep.ClientResponse):
                 self.__dict__['url'] = resp.url.human_repr()
